Seen

Struct Seen 

pub struct Seen<Atom: AtomicNumber = AtomicUsize> { /* private fields */ }
A kind of a bloom filter inspired counter.

May give false positives (since it is aggregated), does not do false negative.

It is used in crate::dedup::Dedup to prevent repeating values (of crate::PotentialPresence for instance).

It achieves interior mutability with atomic numbers so it can be used behind a ref or Arc.

use std::sync::atomic::AtomicU16;
use std::sync::Arc;
use presence::seen::Seen;
let dedup = Arc::new(Seen::<AtomicU16>::builder().build().into_dedup());
assert_eq!(dedup.check(0,b"something"),Ok(true));
assert_eq!(dedup.check(0,b"something"),Ok(false));
assert_eq!(dedup.ease(),Ok(()));
assert_eq!(dedup.check(0,b"something"),Ok(true));

Implementations

Source

impl<Atom: AtomicNumber> Seen<Atom>

pub fn into_dedup<T>(self) -> Dedup<T, Atom>

Source

impl<Atom: AtomicNumber> Seen<Atom>

pub fn builder() -> SeenBuilder<Atom>

Source

impl<Atom: AtomicNumber> Seen<Atom>

pub fn insert(&self, occurrence: &[u8]) -> Option<usize>

Adds the occurrence to the filter.

Returns true if max occurrences have not been reached (inserted). False if not inserted (maxed).

pub fn forget_a_bit(&self)

decrement each counter by one

pub fn forget_all(&self)

clear all counters

pub fn contains(&self, occurrence: &[u8]) -> usize

check how many occurrence there may be

pub fn size(&self) -> usize

pub fn atoms(&self) -> usize

pub fn counter_per_atom(&self) -> usize

pub fn counters(&self) -> usize